==> easypg-0.3.tar.gz: easypg-0.3/easypg/colours.py <==
# Copyright (c) 2007-2011 Nick Efford <nick.efford (at) gmail.com>
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.


"""Some standard RGB colour tuples.

   The tuples defined here are based on the sixteen named colours
   from the HTML 4.01 specification."""


__author__  = 'Nick Efford'
__version__ = '0.3'


white   = (255, 255, 255)
silver  = (191, 191, 191)
grey    = (128, 128, 128)
black   = (  0,   0,   0)
red     = (255,   0,   0)
maroon  = (128,   0,   0)
yellow  = (255, 255,   0)
olive   = (128, 128,   0)
lime    = (  0, 255,   0)
green   = (  0, 128,   0)
aqua    = (  0, 255, 255)
teal    = (  0, 128, 128)
blue    = (  0,   0, 255)
navy    = (  0,   0, 128)
fuchsia = (255,   0, 255)
purple  = (128,   0, 128)

==> easypg-0.4.tar.gz: easypg-0.4/easypg/colours.py <==
# Copyright (c) 2007-2012 Nick Efford <nick.efford (at) gmail.com>
#
# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation
# files (the "Software"), to deal in the Software without
# restriction, including without limitation the rights to use,
# copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following
# conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
# OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
# WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
# OTHER DEALINGS IN THE SOFTWARE.


"""Some standard RGB colour tuples.

   The tuples defined here are based on the sixteen named colours
   from the HTML 4.01 specification."""


__author__  = 'Nick Efford'
__version__ = '0.4'


WHITE   = (255, 255, 255)
SILVER  = (191, 191, 191)
GREY    = (128, 128, 128)
BLACK   = (  0,   0,   0)
RED     = (255,   0,   0)
MAROON  = (128,   0,   0)
YELLOW  = (255, 255,   0)
OLIVE   = (128, 128,   0)
LIME    = (  0, 255,   0)
GREEN   = (  0, 128,   0)
AQUA    = (  0, 255, 255)
TEAL    = (  0, 128, 128)
BLUE    = (  0,   0, 255)
NAVY    = (  0,   0, 128)
FUCHSIA = (255,   0, 255)
PURPLE  = (128,   0, 128)
